OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Added to the list of trusted servers",
    "No server found with ID: %s" : "No server found with ID: %s",
    "Could not remove server" : "Could not remove server",
    "Server is already in the list of trusted servers." : "Server is already in the list of trusted servers.",
    "No server to federate with found" : "No server to federate with found",
    "Could not add server" : "Could not add server",
    "Trusted servers" : "Trusted servers",
    "Federation" : "Federation",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "Federation allows you to connect with other trusted servers to exchange the account directory.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing.",
    "External documentation for Federated Cloud Sharing" : "External documentation for Federated Cloud Sharing",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share.",
    "Each server must validate the other. This process may require a few cron cycles." : "Each server must validate the other. This process may require a few cron cycles.",
    "+ Add trusted server" : "+ Add trusted server",
    "Trusted server" : "Trusted server",
    "Add" : "Add"
},
"nplurals=2; plural=(n != 1);");
